@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012-2015 Kozea
+# Copyright © 2012-2016 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -94,7 +94,7 @@ class Dot(Graph):
             self.y_labels and map(to_str, self.y_labels) or [
                 serie.title['title']
                 if isinstance(serie.title, dict)
-                else serie.title for serie in self.series],
+                else serie.title or '' for serie in self.series],
             self._y_pos))
 
     def _set_view(self):
